==> flutter_flicker-0.83.0.tar.gz: lib/navigation/menu_configuration.dart <==
import 'dart:ui';

import 'package:flutter_flicker/configuration/configuration.dart';
import 'package:flutter_flicker/security/security.dart';
import 'route_configuration.dart';

class MenuConfiguration {
  static Menu get publicMenu {
    return FlickerConfiguration.menus
        .where((element) => element.role == null)
        .first;
  }

  static List<MenuItem> getMenuItemsForCurrentUser() {
    var currentUser = FlickerSecurity.currentUser;
    if (currentUser == null) {
      return publicMenu.items;
    }

    var menuItems = FlickerConfiguration.menus.where((menu) {
      if (menu.role == null) return false;
      return menu.role!.title == currentUser.role!.title;
    });

    if (menuItems.isEmpty) {
      return publicMenu.items;
    }

    return menuItems.first.items;
  }
}

class MenuItem {}

/// Represents a menu item that redirects the user to the specified routeInfo
/// When primaryMenuItem is true the front end layout might display the menu in a more promiment part of the UI
class RouteMenuItem extends MenuItem {
  final RouteInfo routeInfo;
  bool primaryMenuItem;

  RouteMenuItem(this.routeInfo, {this.primaryMenuItem = false});
}

///Represents a grouping of child menu items under a group heading title
class GroupMenuItem extends MenuItem {
  final List<MenuItem> childMenuItems;
  final String title;

  GroupMenuItem({required this.title, required this.childMenuItems});
}

///Represents a visual divider between menu items
class DividerMenuItem extends MenuItem {}

///Represents a menu item where the click action is a custom callback method.
class CallbackMenuItem extends MenuItem {
  final String title;
  final VoidCallback onPressed;
  CallbackMenuItem({required this.title, required this.onPressed});
}

class Menu {
  final FlickerRole? role;
  final List<MenuItem> items;

  Menu({required this.items, this.role});
}

==> flutter_flicker-0.84.0.tar.gz: lib/navigation/menu_configuration.dart <==
import 'dart:ui';

import 'package:flutter_flicker/configuration/configuration.dart';
import 'package:flutter_flicker/security/security.dart';
import 'route_configuration.dart';

class MenuConfiguration {
  static Menu get publicMenu {
    return FlickerConfiguration.menus
        .where((element) => element.role == null)
        .first;
  }

  static List<MenuItem> getMenuItemsForCurrentUser() {
    var currentUser = FlickerSecurity.currentUser;
    if (currentUser == null) {
      return publicMenu.items;
    }

    var menuItems = FlickerConfiguration.menus.where((menu) {
      if (menu.role == null) return false;
      return menu.role!.title == currentUser.role!.title;
    });

    if (menuItems.isEmpty) {
      return publicMenu.items;
    }

    return menuItems.first.items;
  }
}

class MenuItem {
  late String menuText;
  late VoidCallback onTap;
}

/// Represents a menu item that redirects the user to the specified routeInfo
/// When primaryMenuItem is true the front end layout might display the menu in a more promiment part of the UI
class RouteMenuItem extends MenuItem {
  final RouteInfo routeInfo;
  bool primaryMenuItem;

  RouteMenuItem(this.routeInfo, {this.primaryMenuItem = false}) {
    this.menuText = routeInfo.screenName;
    this.onTap = () {
      currentRouteSingleton.navigate(routeInfo);
    };
  }
}

///Represents a grouping of child menu items under a group heading title
class GroupMenuItem extends MenuItem {
  final List<MenuItem> childMenuItems;
  final String title;

  GroupMenuItem({required this.title, required this.childMenuItems});
}

///Represents a visual divider between menu items
class DividerMenuItem extends MenuItem {
  DividerMenuItem() {
    this.menuText = '';
    this.onTap = () {};
  }
}

///Represents a menu item where the click action is a custom callback method.
class CallbackMenuItem extends MenuItem {
  CallbackMenuItem({required String menuText, required VoidCallback onTap}) {
    this.menuText = menuText;
    this.onTap = onTap;
  }
}

class Menu {
  final FlickerRole? role;
  final List<MenuItem> items;

  Menu({required this.items, this.role});
}
